@@ -98,7 +98,9 @@ class BaseRustSocket:
 
         return app_request
 
-    async def connect(self, retries: int = float("inf"), delay: int = 20) -> None:
+    async def connect(
+        self, retries: int = float("inf"), delay: int = 20, on_failure=None
+    ) -> None:
         """
         Attempts to open a connection to the rust game server specified in the constructor
 
@@ -106,7 +108,11 @@ class BaseRustSocket:
         """
         try:
             if self.remote.ws is None:
-                self.remote.connect(retries=retries, delay=delay)
+                await self.remote.connect(
+                    retries=retries,
+                    delay=delay,
+                    on_failure=on_failure,
+                )
                 await self.heartbeat.start_beat()
         except ConnectionRefusedError:
             raise ServerNotResponsiveError("Cannot Connect")
@@ -237,7 +243,12 @@ class BaseRustSocket:
             coro = coro.get_coro()
 
         if asyncio.iscoroutinefunction(coro):
-            cmd_data = CommandData(coro, asyncio.get_event_loop(), aliases, alias_func)
+            cmd_data = CommandData(
+                coro,
+                asyncio.get_event_loop_policy().get_event_loop(),
+                aliases,
+                alias_func,
+            )
             self.remote.command_handler.register_command(cmd_data)
             return RegisteredListener(coro.__name__, (cmd_data.coro, cmd_data.loop))
 
@@ -249,7 +260,12 @@ class BaseRustSocket:
             if isinstance(coro, RegisteredListener):
                 coro = coro.get_coro()
 
-            cmd_data = CommandData(coro, asyncio.get_event_loop(), aliases, alias_func)
+            cmd_data = CommandData(
+                coro,
+                asyncio.get_event_loop_policy().get_event_loop(),
+                aliases,
+                alias_func,
+            )
             self.remote.command_handler.register_command(cmd_data)
             return RegisteredListener(coro.__name__, (cmd_data.coro, cmd_data.loop))
 
@@ -266,7 +282,7 @@ class BaseRustSocket:
         if isinstance(coro, RegisteredListener):
             coro = coro.get_coro()
 
-        data = (coro, asyncio.get_event_loop())
+        data = (coro, asyncio.get_event_loop_policy().get_event_loop())
         listener = RegisteredListener("team_changed", data)
         self.remote.event_handler.register_event(listener)
         return listener
@@ -282,7 +298,7 @@ class BaseRustSocket:
         if isinstance(coro, RegisteredListener):
             coro = coro.get_coro()
 
-        data = (coro, asyncio.get_event_loop())
+        data = (coro, asyncio.get_event_loop_policy().get_event_loop())
         listener = RegisteredListener("chat_message", data)
 
         self.remote.event_handler.register_event(listener)
@@ -333,7 +349,7 @@ class BaseRustSocket:
                     )
                 )
 
-            loop = asyncio.get_event_loop()
+            loop = asyncio.get_event_loop_policy().get_event_loop()
             future = asyncio.run_coroutine_threadsafe(get_entity(self, eid), loop)
             future.add_done_callback(entity_event_callback)
 
@@ -363,7 +379,7 @@ class BaseRustSocket:
         if not self.marker_listener:
             raise ValueError("Marker listener not started")
 
-        data = (coro, asyncio.get_event_loop())
+        data = (coro, asyncio.get_event_loop_policy().get_event_loop())
         listener = RegisteredListener("map_marker", data)
         self.marker_listener.add_listener(listener)
         return listener
@@ -379,7 +395,7 @@ class BaseRustSocket:
         if isinstance(coro, RegisteredListener):
             coro = coro.get_coro()
 
-        data = (coro, asyncio.get_event_loop())
+        data = (coro, asyncio.get_event_loop_policy().get_event_loop())
         listener = RegisteredListener("protobuf_received", data)
         self.remote.event_handler.register_event(listener)
         return listener
