@@ -76,3 +76,14 @@ class EventHandler:
             except ValueError:
                 pass
             setattr(self, listener.listener_id, events)
+
+    def clear_entity_events(self) -> None:
+
+        to_remove = []
+        for name in vars(self).keys():
+            # only remove entity events
+            if name not in ["team_changed", "chat_message", "protobuf_received"]:
+                to_remove.append(name)
+
+        for name in to_remove:
+            delattr(self, name)
