@@ -19,7 +19,18 @@ CLOSED = 3
 
 
 class RustWebsocket(websocket.WebSocket):
-    def __init__(self, ip, port, remote, use_proxy, magic_value, use_test_server):
+    def __init__(
+        self,
+        ip,
+        port,
+        remote,
+        use_proxy,
+        magic_value,
+        use_test_server,
+        on_failure,
+        delay,
+        loop,
+    ):
 
         self.ip = ip
         self.port = port
@@ -32,11 +43,14 @@ class RustWebsocket(websocket.WebSocket):
         self.magic_value = magic_value
         self.use_test_server = use_test_server
         self.outgoing_conversation_messages = []
+        self.on_failure = on_failure
+        self.delay = delay
+        self.loop = loop
 
         super().__init__()
 
-    def connect(
-        self, retries=float("inf"), ignore_open_value: bool = False, delay: int = 20
+    async def connect(
+        self, retries=float("inf"), ignore_open_value: bool = False
     ) -> None:
 
         if (
@@ -70,13 +84,32 @@ class RustWebsocket(websocket.WebSocket):
                     super().connect(address)
                     self.connected_time = time.time()
                     break
-                except Exception:
-                    self.logger.warning(
-                        f"{datetime.now().strftime('%d/%m/%Y %H:%M:%S')} "
-                        f"[RustPlus.py] Cannot Connect to server. Retrying in {str(delay)} seconds"
-                    )
+                except Exception as exception:
+
+                    print_error = True
+
+                    if not isinstance(exception, KeyboardInterrupt):
+                        # Run the failure callback
+                        try:
+                            if self.on_failure is not None:
+                                if asyncio.iscoroutinefunction(self.on_failure):
+                                    val = await self.on_failure()
+                                else:
+                                    val = self.on_failure()
+
+                                if val is not None:
+                                    print_error = val
+
+                        except Exception as e:
+                            self.logger.warning(e)
+
+                    if print_error:
+                        self.logger.warning(
+                            f"{datetime.now().strftime('%d/%m/%Y %H:%M:%S')} "
+                            f"[RustPlus.py] Cannot Connect to server. Retrying in {str(self.delay)} second/s"
+                        )
                     attempts += 1
-                    time.sleep(delay)
+                    time.sleep(self.delay)
 
             self.connection_status = CONNECTED
 
@@ -131,7 +164,9 @@ class RustWebsocket(websocket.WebSocket):
                     self.logger.warning(
                         f"{datetime.now().strftime('%d/%m/%Y %H:%M:%S')} [RustPlus.py] Connection interrupted, Retrying"
                     )
-                    self.connect(ignore_open_value=True)
+                    asyncio.run_coroutine_threadsafe(
+                        self.connect(ignore_open_value=True), self.loop
+                    ).result()
                     continue
                 return
 
